# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from .goal import Goal

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class AnalyzeCall(pydantic.BaseModel):
    goal: Goal = pydantic.Field()
    """
    This is the overall purpose of the call. Provides context for the analysis to guide how the questions/transcripts are interpreted.
    """

    questions: typing.List[typing.List[str]] = pydantic.Field()
    """
    An array of questions to be analyzed for the call.
    
    Each question should be an array with two elements - the question text and the expected answer type (e.g., “string”, “boolean”).
    
    Fairly flexible in terms of the expected answer type, and unanswerable questions will default to `null`.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}
