# This file was auto-generated by Fern from our API Definition.

import typing

LegalStructureEnum = typing.Literal[
    "Partnership", "Limited Liability Corporation", "Co-operative", "Non-profit Corporation", "Corporation"
]
