# This file was auto-generated by Fern from our API Definition.

import typing

VerticalEnum = typing.Literal[
    "AUTOMOTIVE",
    "AGRICULTURE",
    "BANKING",
    "CONSTRUCTION",
    "CONSUMER",
    "EDUCATION",
    "ENGINEERING",
    "ENERGY",
    "OIL_AND_GAS",
    "FAST_MOVING_CONSUMER_GOODS",
    "FINANCIAL",
    "FINTECH",
    "FOOD_AND_BEVERAGE",
    "GOVERNMENT",
    "HEALTHCARE",
    "HOSPITALITY",
    "INSURANCE",
    "LEGAL",
    "MANUFACTURING",
    "MEDIA",
    "ONLINE",
    "PROFESSIONAL_SERVICES",
    "RAW_MATERIALS",
    "REAL_ESTATE",
    "RELIGION",
    "RETAIL",
    "JEWELRY",
    "TECHNOLOGY",
    "TELECOMMUNICATIONS",
    "TRANSPORTATION",
    "TRAVEL",
    "ELECTRONICS",
    "NOT_FOR_PROFIT",
]
